==> views_access_conditions-1.0.0.tar.gz: views_access_conditions/tests/modules/views_access_conditions_test/src/Plugin/Condition/TestConditionTwo.php <==
<?php

declare(strict_types=1);

namespace Drupal\views_access_conditions_test\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a second test condition.
 *
 * @Condition(
 *   id = "test_condition_two",
 *   label = @Translation("Test condition two"),
 * )
 */
class TestConditionTwo extends ConditionPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['condition_met'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Condition is met'),
      '#default_value' => $this->configuration['condition_met'] ?? FALSE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['condition_met'] = $form_state->getValue('condition_met');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'condition_met' => FALSE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    return !empty($this->configuration['condition_met']);
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->t('Test condition two is @state', [
      '@state' => !empty($this->configuration['condition_met']) ? $this->t('met') : $this->t('not met'),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function isNegated(): bool {
    return FALSE;
  }

}

==> views_access_conditions-1.0.1.tar.gz: views_access_conditions/tests/modules/views_access_conditions_test/src/Plugin/Condition/TestConditionTwo.php <==
<?php

declare(strict_types=1);

namespace Drupal\views_access_conditions_test\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Condition\Attribute\Condition;

/**
 * Provides a second test condition.
 */
#[Condition(
  id: "test_condition_two",
  label: new TranslatableMarkup("Test condition two")
)]
class TestConditionTwo extends ConditionPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['condition_met'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Condition is met'),
      '#default_value' => $this->configuration['condition_met'] ?? FALSE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['condition_met'] = $form_state->getValue('condition_met');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'condition_met' => FALSE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    return !empty($this->configuration['condition_met']);
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->t('Test condition two is @state', [
      '@state' => !empty($this->configuration['condition_met']) ? $this->t('met') : $this->t('not met'),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function isNegated(): bool {
    return FALSE;
  }

}
